{ config
, lib
, ...
}:

with lib;
let
  cfg = config.my.programs.hyprland;

  mkRule = rule: windowRegexes: "windowrulev2 = ${rule},${concatStringsSep "," windowRegexes}";
  mkRules = rules: windowRegexes: concatStringsSep "\n" (map (flip mkRule windowRegexes) rules);
in
''
  #
  # Please note not all available settings / options are set here.
  # For a full list, see the wiki
  #

  # See https://wiki.hyprland.org/Configuring/Monitors/
  ${concatLines (map (x: "monitor=${x}") cfg.monitors)}

  # See https://wiki.hyprland.org/Configuring/Keywords/ for more

  # For all categories, see https://wiki.hyprland.org/Configuring/Variables/
  input {
      kb_layout = ${concatStringsSep "," cfg.keyboardLayouts}
      kb_variant =
      kb_model =
      kb_options = grp:win_space_toggle,caps:escape
      kb_rules =

      follow_mouse = 1

      touchpad {
          natural_scroll = yes
      }

      sensitivity = 0 # -1.0 - 1.0, 0 means no modification.
  }

  general {
      # See https://wiki.hyprland.org/Configuring/Variables/ for more

      gaps_in = 3
      gaps_out = 3
      border_size = 2
      col.active_border = rgba(1affffee)
      col.inactive_border = rgba(595959aa)

      cursor_inactive_timeout = 1

      layout = dwindle
  }

  decoration {
      # See https://wiki.hyprland.org/Configuring/Variables/ for more

      rounding = 3
      blur {
        enabled = ${boolToString cfg.blur}
        size = 3
        passes = 3
        new_optimizations = on
      }

      drop_shadow = ${boolToString cfg.shadows}
      shadow_range = 10
      shadow_render_power = 2

      # col.shadow = rgba(1a1a1aee)
  }

  animations {
      enabled = yes

      # see https://wiki.hyprland.org/Configuring/Animations/ for more

      bezier = sine, 0.445, 0.05, 0.55, 0.95
      bezier = quad, 0.455, 0.03, 0.515, 0.955
      bezier = cubic, 0.68, -0.55, 0.265, 1.55
      bezier = quart, 0.77, 0, 0.175, 1
      bezier = quint, 0.86, 0, 0.07, 1
      bezier = expo, 1, 0, 0, 1
      bezier = circ, 0.785, 0.135, 0.15, 0.86
      bezier = back, 0.68, -0.55, 0.265, 1.55

      animation = windows, 1, 4, default, slide
      animation = windowsIn, 1, 4, circ, slide
      animation = windowsOut, 1, 4, circ, slide
      animation = border, 1, 2, sine
      animation = fade, 1, 4, sine
      animation = workspaces, 1, 5, circ, slidevert
  }

  dwindle {
      # See https://wiki.hyprland.org/Configuring/Dwindle-Layout/ for more
      pseudotile = yes # master switch for pseudotiling. Enabling is bound to mainMod + P in the keybinds section below
      preserve_split = yes # you probably want this
      no_gaps_when_only = true
  }

  master {
      # See https://wiki.hyprland.org/Configuring/Master-Layout/ for more
      no_gaps_when_only = true
      new_is_master = false
  }

  gestures {
      # See https://wiki.hyprland.org/Configuring/Variables/ for more
      workspace_swipe = on
  }

  misc {
    vrr = 0
    mouse_move_enables_dpms = true
    key_press_enables_dpms = true
    force_default_wallpaper = 0
  }

  # See https://wiki.hyprland.org/Configuring/Window-Rules/ for more
  # Firefox Sharing Indicator
  ${mkRules ["float" "move 49% 40" "noborder" "nofullscreenrequest"] ["title:^(.*Sharing Indicator.*)$"]}

  # Emacs
  windowrulev2 = opaque, class:^(emacs)$

  # Fullscreen Applications
  ${mkRules ["opaque" "noblur" "noborder" "noshadow" "forceinput"] ["fullscreen:1"]}

  ${mkRules ["tile" "opaque"] ["class:^(neovide)$"]}

  # fix xwayland apps
  windowrulev2 = rounding 0, xwayland:1, floating:1
  windowrulev2 = center, class:^(.*jetbrains.*)$, title:^(Confirm Exit|Open Project|win424|win201|splash)$
  windowrulev2 = size 640 400, class:^(.*jetbrains.*)$, title:^(splash)$
  ${mkRules ["opaque" "noshadow" "noblur" "noanim" "move cursor 5 5"] ["class:^(.*jetbrains-.*)$"]}

  # See https://wiki.hyprland.org/Configuring/Keywords/ for more
  $mainMod = SUPER
  $windowMod = ALT

  # Example binds, see https://wiki.hyprland.org/Configuring/Binds/ for more

  # Window binds
  bind = $mainMod       , F , togglefloating ,
  bind = $mainMod       , P , pseudo         ,
  bind = $mainMod       , Q , killactive     ,
  bind = $mainMod       , T , togglesplit    ,
  bind = $mainMod SHIFT , F , fullscreen     ,

  # Program binds
  bind = $mainMod       , B      , exec , rofi-bluetooth
  bind = $mainMod       , C      , exec , rofi -show calc -modi calc -no-show-match -no-sort | wl-copy
  bind = $mainMod       , D      , exec , hyprctl keyword general:layout dwindle
  bind = $mainMod       , M      , exec , hyprctl keyword general:layout master
  bind = $mainMod       , R      , exec , rofi -show combi
  bind = $mainMod       , RETURN , exec , kitty
  bind = $mainMod SHIFT , RETURN , exec , kitty -- tmux new "ts || tn home ~"

  # XF86 keys
  binde = , XF86AudioLowerVolume  , exec , pamixer -d 5
  binde = , XF86AudioRaiseVolume  , exec , pamixer -i 5
  bind  = , XF86AudioMute         , exec , pamixer -t
  bind  = , XF86AudioNext         , exec , playerctl -p "spotifyd,firefox" next
  bind  = , XF86AudioPlay         , exec , playerctl -p "spotifyd,firefox" play-pause
  bind  = , XF86AudioPrev         , exec , playerctl -p "spotifyd,firefox" previous

  # Move focus with mainMod + hjkl
  binde = $mainMod , H , movefocus , l
  binde = $mainMod , L , movefocus , r
  binde = $mainMod , K , movefocus , u
  binde = $mainMod , J , movefocus , d

  # Change current active window size with mainMod + SHIFT + hjkl
  binde = $mainMod SHIFT , H , resizeactive , -10 0
  binde = $mainMod SHIFT , J , resizeactive , 0 10
  binde = $mainMod SHIFT , K , resizeactive , 0 -10
  binde = $mainMod SHIFT , L , resizeactive , 10 0

  # Move current active window with mainMod + ALT + hjkl
  bind = $mainMod ALT , H , movewindow , l
  bind = $mainMod ALT , J , movewindow , d
  bind = $mainMod ALT , K , movewindow , u
  bind = $mainMod ALT , L , movewindow , r

  # Switch workspaces with mainMod + [0-9]
  bind = $mainMod , 1 , workspace , 1
  bind = $mainMod , 2 , workspace , 2
  bind = $mainMod , 3 , workspace , 3
  bind = $mainMod , 4 , workspace , 4
  bind = $mainMod , 5 , workspace , 5
  bind = $mainMod , 6 , workspace , 6
  bind = $mainMod , 7 , workspace , 7
  bind = $mainMod , 8 , workspace , 8
  bind = $mainMod , 9 , workspace , 9
  bind = $mainMod , 0 , workspace , 10

  # Move active window to a workspace with mainMod + SHIFT + [0-9]
  bind = $mainMod SHIFT , 1 , movetoworkspace , 1
  bind = $mainMod SHIFT , 2 , movetoworkspace , 2
  bind = $mainMod SHIFT , 3 , movetoworkspace , 3
  bind = $mainMod SHIFT , 4 , movetoworkspace , 4
  bind = $mainMod SHIFT , 5 , movetoworkspace , 5
  bind = $mainMod SHIFT , 6 , movetoworkspace , 6
  bind = $mainMod SHIFT , 7 , movetoworkspace , 7
  bind = $mainMod SHIFT , 8 , movetoworkspace , 8
  bind = $mainMod SHIFT , 9 , movetoworkspace , 9
  bind = $mainMod SHIFT , 0 , movetoworkspace , 10

  # Scroll through existing workspaces with mainMod + scroll
  bind = $mainMod , mouse_down , workspace , e+1
  bind = $mainMod , mouse_up   , workspace , e-1

  # Move/resize windows with mainMod + LMB/RMB and dragging
  bindm = $mainMod , mouse:272 , movewindow
  bindm = $mainMod , mouse:273 , resizewindow

  # Toggle waybar
  bindr = $mainMod , SUPER_L , exec , pkill -USR1 waybar

  # Extra Config
  ${cfg.extraConfig}
''
