{ config, lib, pkgs, inputs, ... }:

with lib;
let
  cfg = config.my.programs.nvim;
in
{
  imports = lib.my.listModulesRec ./plugins;

  options.my.programs.nvim.enable = mkEnableOption "nvim";

  config = mkIf cfg.enable {
    home-manager.users.moritz = {
      home.packages = with pkgs; [
        (
          if config.my.programs.hyprland.enable
          then neovide-hyprland
          else neovide
        )
      ];

      programs.neovim = {
        enable = true;
        package = inputs.neovim-nightly-overlay.packages.${pkgs.system}.default;
        vimAlias = true;
        vimdiffAlias = true;
        withNodeJs = true;
        withPython3 = true;
        extraPackages = with pkgs;
          [
            alejandra
            checkmake
            codespell
            deadnix
            dotenv-linter
            fish
            jq
            nil
            nixd
            nixpkgs-fmt
            nodePackages.bash-language-server
            nodePackages.jsonlint
            shellcheck
            shfmt
            statix
            taplo
            yamlfix
            yamllint
          ];
        extraLuaConfig = readFile ./options.lua;
        lazy.enable = true;
      };
    };
  };
}
